@@ -3,8 +3,10 @@
 #' storing information about all available Ensembl Biomart databases.
 #' @author Hajk-Georg Drost
 #' @examples
+#' \dontrun{
 #' # get a table of all available databases from Ensembl Biomart
-#'  getMarts()
+#' getMarts()
+#'  }
 #' @seealso \code{\link{getDatasets}}, \code{\link{getAttributes}}, 
 #' \code{\link{getFilters}}, \code{\link{organismBM}}, 
 #' \code{\link{organismFilters}}, \code{\link{organismAttributes}}
@@ -13,9 +15,16 @@ getMarts <- function(){
     
     submarts <- c("ensembl", "plants", "fungi", "protists", "metazoa")
     submarts.df <- vector("list", length(submarts))
+    
+    tryCatch({
     for (i in seq_along(submarts)) {
         submarts.df[i] <- list(getSubMarts(submarts[i]))
     }
+        }, error = function(e)
+        stop(
+            "It seems like the BioMart server could not be reached. This is either due to a server maintainence downtime or due to no internet connection on your side.",
+            call. = FALSE
+        ))
         
     return(dplyr::bind_rows(submarts.df))
 }
