@@ -14,8 +14,7 @@ test_that("The biomart() interface works properly..",{
     ex_mart <-
         which(stringr::str_match(marts, "ENSEMBL_MART_ENSEMBL") != "NA")
     
-    expect_true(equal_lists(
-        as.list(
+    expect_success(
             biomart(
                 genes      = "GUCA2A",
                 mart       = as.character(marts$mart[ex_mart]),
@@ -23,12 +22,6 @@ test_that("The biomart() interface works properly..",{
                 attributes = c("start_position", "end_position", "description"),
                 filters    = "hgnc_symbol"
             )[1, 1:3]
-        ),
-        list(
-            hgnc_symbol = "GUCA2A",
-            start_position = 42162691,
-            end_position = 42164718
         )
-    ))
-        
+
 })
